@@ -6,8 +6,10 @@ from rail.core.stage import RailStage
 from rail.core.data import QPHandle
 from rail.estimation.algos import naiveStack, pointEstimateHist
 from rail.estimation.algos import varInference
+from rail.core.utils import RAILDIR
 
-testdata = 'tests/data/output_BPZ_lite.fits'
+
+testdata = os.path.join(RAILDIR, 'rail/examples/testdata/output_BPZ_lite.fits')
 DS = RailStage.data_store
 DS.__class__.allow_overwrite = True
 
